/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

package org.glite.ce.creamapi.delegationmanagement;

import java.util.List;


public interface DelegationManagerInterface {
    public static final String DELEGATION_DATABASE_NAME = "delegationdb";
    public static final String DELEGATION_DATASOURCE_NAME = "java:comp/env/jdbc/dlg";
   
    public void deleteDelegation(Delegation delegation) throws DelegationException, DelegationManagementException;

    public void deleteDelegation(String delegationId, String dn, String localUser) throws DelegationException, DelegationManagementException;

    public void destroy();

    public Delegation getDelegation(String delegationId, String dn, String localUser) throws DelegationException, DelegationManagementException;

    /**
     * This method returns the delegation suffix of the database identified by the datasource parameter.
     * @param datasourceName the datasource of the database
     * @return DelegationSuffix the delegation suffix.  If an exception occurs, the method returns null.
     */
    public String getDelegationSuffix() throws DelegationException, DelegationManagementException;
    
    public List<Delegation> getExpiredDelegation() throws DelegationException, DelegationManagementException;
    
    public void insertDelegation(Delegation delegation) throws DelegationException, DelegationManagementException;

    public List<Delegation> listDelegations(String dn, String localUser) throws DelegationException, DelegationManagementException;

    public void updateDelegation(Delegation delegation) throws DelegationException, DelegationManagementException;
}
